@@ -21,7 +21,7 @@ BEGIN
     PUSHBUTTON      "Help",ID_HELP,99,162,48,15
     PUSHBUTTON      "Close",IDCANCEL,151,162,48,15
     PUSHBUTTON      "Activate instalation",IDC_BUTTON1,74,76,76,18
-    CTEXT           "My very good program",IDC_STATIC1,56,21,109,19,SS_SUNKEN
+    CTEXT           "My very" " good program",IDC_STATIC1,56,21,109,19,SS_SUNKEN
     CTEXT           "You can use it without registering it",IDC_STATIC,35,131,128,19,SS_SUNKEN
     PUSHBUTTON      "Offline",IDC_OFFLINE,149,108,42,13
     PUSHBUTTON      "See license",IDC_LICENCIA,10,162,85,15
@@ -54,6 +54,10 @@ POFILE = """
 #: DIALOGEX.IDD_REGGHC_DIALOG.CAPTION
 msgid "License dialog"
 msgstr "Licenční dialog"
+
+#: DIALOGEX.IDD_REGGHC_DIALOG.CTEXT.IDC_STATIC1
+msgid "My very good program"
+msgstr "Mój bardzo dobry program"
 """
 
 
@@ -80,6 +84,7 @@ class TestPO2RCCommand(test_convert.TestConvertCommand):
             rc_result = rcfile(handle)
         assert len(rc_result.units) == 14
         assert rc_result.units[0].target == "Licenční dialog"
+        assert rc_result.units[4].target == "Mój bardzo dobry program"
 
     def test_convert_comment(self):
         self.create_testfile(
@@ -150,3 +155,71 @@ msgstr "Zkopirovano"
             rc_result = rcfile(handle)
         assert len(rc_result.units) == 1
         assert rc_result.units[0].target == "Zkopirovano"
+
+    def test_convert_double_string(self):
+        self.create_testfile(
+            "simple.rc",
+            """
+STRINGTABLE
+BEGIN
+    IDS_COPIED              "Copied"
+    IDS_XCOPIED             "Copied"
+END
+""",
+        )
+        self.create_testfile(
+            "simple.po",
+            """
+#: STRINGTABLE.IDS_COPIED
+msgid "Copied"
+msgstr "Zkopirovano"
+""",
+        )
+        self.run_command(
+            template="simple.rc", i="simple.po", o="output.rc", l="LANG_CZECH"
+        )
+        with self.open_testfile("output.rc") as handle:
+            rc_result = rcfile(handle)
+        assert len(rc_result.units) == 2
+        assert rc_result.units[0].target == "Zkopirovano"
+        assert rc_result.units[1].target == "Copied"
+
+    def test_convert_popup(self):
+        self.create_testfile(
+            "simple.rc",
+            """
+IDR_MAINFRAME MENU
+BEGIN
+   POPUP "&File"
+   BEGIN
+       MENUITEM "&New\tCrtl+N",                ID_FILE_NEW
+       MENUITEM "&Open...\tCtrl+O",            ID_FILE_OPEN
+       MENUITEM "&Exit",                       ID_FILE_CLOSE
+   END
+   POPUP "&View"
+   BEGIN
+       MENUITEM "&Toolbar",                    ID_VIEW_STATUS_BAR
+   END
+   POPUP "&Help"
+   BEGIN
+       MENUITEM "&About...",                   ID_APP_ABOUT
+   END
+END
+""",
+        )
+        self.create_testfile(
+            "simple.po",
+            """
+#: MENU.IDR_MAINFRAME.POPUP.CAPTION
+msgid "&Help"
+msgstr "&Pomoc"
+""",
+        )
+        self.run_command(
+            template="simple.rc", i="simple.po", o="output.rc", l="LANG_CZECH"
+        )
+        with self.open_testfile("output.rc") as handle:
+            rc_result = rcfile(handle)
+        assert len(rc_result.units) == 8
+        assert rc_result.units[0].target == "&File"
+        assert rc_result.units[6].target == "&Pomoc"
