@@ -261,6 +261,17 @@ userItems.limit[\=0] = No items can be added.
         assert not isinstance(propunit.target, multistring)
         assert propunit.source == "No items can be added."
 
+    def test_non_plurals(self):
+        propsource = r"""
+Ps[Pd]_unexpected = Test string
+"""
+        propfile = self.propparse(propsource)
+
+        assert len(propfile.units) == 1
+        propunit = propfile.units[0]
+        assert propunit.name == "Ps[Pd]_unexpected"
+        assert propunit.source == "Test string"
+
 
 class TestProp(test_monolingual.TestMonolingualStore):
     StoreClass = properties.propfile
@@ -327,23 +338,39 @@ class TestProp(test_monolingual.TestMonolingualStore):
     def test_whitespace_handling(self):
         """check that we remove extra whitespace around property"""
         whitespaces = (
-            ("key = value", "key", "value"),  # Standard for baseline
-            (" key =  value", "key", "value"),  # Extra \s before key and value
             (
+                # Standard for baseline
+                "key = value",
+                "key",
+                "value",
+                "key=value\n",
+            ),
+            (
+                # Extra \s before key and value
+                " key =  value",
+                "key",
+                "value",
+                "key=value\n",
+            ),
+            (
+                # extra space at start and end of key
                 "\\ key\\ = value",
                 "\\ key\\ ",
                 "value",
-            ),  # extra space at start and end of key
+                "\\ key\\ =value\n",
+            ),
             (
+                # extra space at start end end of value
                 "key = \\ value ",
                 "key",
                 " value ",
-            ),  # extra space at start end end of value
+                "key=\\ value \n",
+            ),
         )
-        for propsource, key, value in whitespaces:
+        for propsource, key, value, expected in whitespaces:
             propfile = self.propparse(propsource)
             propunit = propfile.units[0]
-            print(repr(propsource), repr(propunit.name), repr(propunit.source))
+            print(f"{propsource!r}, {propunit.name!r}, {propunit.source!r}")
             assert propunit.name == key
             assert propunit.source == value
             # let's reparse the output to ensure good serialisation->parsing roundtrip:
@@ -351,6 +378,8 @@ class TestProp(test_monolingual.TestMonolingualStore):
             propunit = propfile.units[0]
             assert propunit.name == key
             assert propunit.source == value
+            propunit.target = value
+            assert bytes(propfile).decode() == expected
 
     def test_key_value_delimiters_simple(self):
         """
@@ -569,6 +598,22 @@ key=value
         # - every line ends with ";"
         assert bytes(propfile).strip(b"\n\x00") == propsource.strip(b"\n\x00")
 
+    def test_mac_strings_double_backslashes(self):
+        """test that double backslashes are encoded correctly"""
+        propsource = (
+            r""""key" = "value with \\ signs but also a \n line break";""".encode(
+                "utf-16"
+            )
+        )
+        propfile = self.propparse(propsource, personality="strings")
+        propunit = propfile.units[0]
+        assert propunit.name == "key"
+        assert propunit.source == "value with \\ signs but also a \n line break"
+        assert (
+            propfile.personality.encode(propunit.source)
+            == r"value with \\ signs but also a \n line break"
+        )
+
     def test_override_encoding(self):
         """test that we can override the encoding of a properties file"""
         propsource = "key = value".encode("cp1252")
